@@ -1,14 +1,14 @@
-import typing
-import datetime as _datetime
+import typing  # noqa: F401
+import datetime as _datetime  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.latest.meta_v1 import ListMeta
-from kuber.latest.meta_v1 import ObjectMeta
-from kuber.latest.meta_v1 import Status
-from kuber.latest.meta_v1 import StatusDetails
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.latest.meta_v1 import ListMeta  # noqa: F401
+from kuber.latest.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.latest.meta_v1 import Status  # noqa: F401
+from kuber.latest.meta_v1 import StatusDetails  # noqa: F401
 
 
 class BoundObjectReference(_kuber_definitions.Definition):
@@ -268,7 +268,10 @@ class TokenRequest(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_token_request", "read_token_request"]
+        names = [
+            "read_namespaced_token_request",
+            "read_token_request",
+        ]
 
         response = _kube_api.execute(
             action="read",
@@ -710,7 +713,10 @@ class TokenReview(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_token_review", "read_token_review"]
+        names = [
+            "read_namespaced_token_review",
+            "read_token_review",
+        ]
 
         response = _kube_api.execute(
             action="read",
