@@ -1,15 +1,15 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.latest.meta_v1 import ListMeta
-from kuber.latest.core_v1 import LoadBalancerStatus
-from kuber.latest.meta_v1 import ObjectMeta
-from kuber.latest.meta_v1 import Status
-from kuber.latest.meta_v1 import StatusDetails
-from kuber.latest.core_v1 import TypedLocalObjectReference
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.latest.meta_v1 import ListMeta  # noqa: F401
+from kuber.latest.core_v1 import LoadBalancerStatus  # noqa: F401
+from kuber.latest.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.latest.meta_v1 import Status  # noqa: F401
+from kuber.latest.meta_v1 import StatusDetails  # noqa: F401
+from kuber.latest.core_v1 import TypedLocalObjectReference  # noqa: F401
 
 
 class HTTPIngressPath(_kuber_definitions.Definition):
@@ -393,7 +393,10 @@ class Ingress(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_ingress", "read_ingress"]
+        names = [
+            "read_namespaced_ingress",
+            "read_ingress",
+        ]
 
         response = _kube_api.execute(
             action="read",
