@@ -1,14 +1,14 @@
-import typing
-import datetime as _datetime
+import typing  # noqa: F401
+import datetime as _datetime  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.pre.meta_v1 import ListMeta
-from kuber.pre.meta_v1 import ObjectMeta
-from kuber.pre.meta_v1 import Status
-from kuber.pre.meta_v1 import StatusDetails
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.pre.meta_v1 import ListMeta  # noqa: F401
+from kuber.pre.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.pre.meta_v1 import Status  # noqa: F401
+from kuber.pre.meta_v1 import StatusDetails  # noqa: F401
 
 
 class APIService(_kuber_definitions.Resource):
@@ -174,7 +174,10 @@ class APIService(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_api_service", "read_api_service"]
+        names = [
+            "read_namespaced_api_service",
+            "read_api_service",
+        ]
 
         response = _kube_api.execute(
             action="read",
