@@ -1,26 +1,26 @@
-import typing
-import datetime as _datetime
+import typing  # noqa: F401
+import datetime as _datetime  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_19.core_v1 import Container
-from kuber.v1_19.core_v1 import ContainerPort
-from kuber.v1_19.core_v1 import EnvFromSource
-from kuber.v1_19.core_v1 import EnvVar
-from kuber.v1_19.batch_v1 import JobSpec
-from kuber.v1_19.core_v1 import Lifecycle
-from kuber.v1_19.meta_v1 import ListMeta
-from kuber.v1_19.meta_v1 import ObjectMeta
-from kuber.v1_19.core_v1 import ObjectReference
-from kuber.v1_19.core_v1 import Probe
-from kuber.v1_19.core_v1 import ResourceRequirements
-from kuber.v1_19.core_v1 import SecurityContext
-from kuber.v1_19.meta_v1 import Status
-from kuber.v1_19.meta_v1 import StatusDetails
-from kuber.v1_19.core_v1 import VolumeDevice
-from kuber.v1_19.core_v1 import VolumeMount
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_15.core_v1 import Container  # noqa: F401
+from kuber.v1_15.core_v1 import ContainerPort  # noqa: F401
+from kuber.v1_15.core_v1 import EnvFromSource  # noqa: F401
+from kuber.v1_15.core_v1 import EnvVar  # noqa: F401
+from kuber.v1_15.batch_v1 import JobSpec  # noqa: F401
+from kuber.v1_15.core_v1 import Lifecycle  # noqa: F401
+from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_15.core_v1 import ObjectReference  # noqa: F401
+from kuber.v1_15.core_v1 import Probe  # noqa: F401
+from kuber.v1_15.core_v1 import ResourceRequirements  # noqa: F401
+from kuber.v1_15.core_v1 import SecurityContext  # noqa: F401
+from kuber.v1_15.meta_v1 import Status  # noqa: F401
+from kuber.v1_15.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_15.core_v1 import VolumeDevice  # noqa: F401
+from kuber.v1_15.core_v1 import VolumeMount  # noqa: F401
 
 
 class CronJob(_kuber_definitions.Resource):
@@ -53,8 +53,8 @@ class CronJob(_kuber_definitions.Resource):
     def metadata(self) -> "ObjectMeta":
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -65,8 +65,8 @@ class CronJob(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union["ObjectMeta", dict]):
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -80,8 +80,8 @@ class CronJob(_kuber_definitions.Resource):
         """
         Specification of the desired behavior of a cron job,
         including the schedule. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#spec-and-status
         """
         return typing.cast(
             "CronJobSpec",
@@ -93,8 +93,8 @@ class CronJob(_kuber_definitions.Resource):
         """
         Specification of the desired behavior of a cron job,
         including the schedule. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -107,8 +107,8 @@ class CronJob(_kuber_definitions.Resource):
     def status(self) -> "CronJobStatus":
         """
         Current status of a cron job. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#spec-and-status
         """
         return typing.cast(
             "CronJobStatus",
@@ -119,8 +119,8 @@ class CronJob(_kuber_definitions.Resource):
     def status(self, value: typing.Union["CronJobStatus", dict]):
         """
         Current status of a cron job. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -183,10 +183,6 @@ class CronJob(_kuber_definitions.Resource):
             "SecurityContext",
             _kuber_definitions.InternalValue,
         ] = _kuber_definitions.UNCHANGED_VALUE,
-        startup_probe: typing.Union[
-            "Probe",
-            _kuber_definitions.InternalValue,
-        ] = _kuber_definitions.UNCHANGED_VALUE,
         stdin: typing.Union[
             bool,
             _kuber_definitions.InternalValue,
@@ -235,7 +231,6 @@ class CronJob(_kuber_definitions.Resource):
             "readiness_probe": readiness_probe,
             "resources": resources,
             "security_context": security_context,
-            "startup_probe": startup_probe,
             "stdin": stdin,
             "stdin_once": stdin_once,
             "termination_message_path": termination_message_path,
@@ -348,7 +343,10 @@ class CronJob(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_cron_job", "read_cron_job"]
+        names = [
+            "read_namespaced_cron_job",
+            "read_cron_job",
+        ]
 
         response = _kube_api.execute(
             action="read",
@@ -484,8 +482,8 @@ class CronJobList(_kuber_definitions.Collection):
     def metadata(self) -> "ListMeta":
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ListMeta",
@@ -496,8 +494,8 @@ class CronJobList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union["ListMeta", dict]):
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -780,10 +778,6 @@ class CronJobSpec(_kuber_definitions.Definition):
             "SecurityContext",
             _kuber_definitions.InternalValue,
         ] = _kuber_definitions.UNCHANGED_VALUE,
-        startup_probe: typing.Union[
-            "Probe",
-            _kuber_definitions.InternalValue,
-        ] = _kuber_definitions.UNCHANGED_VALUE,
         stdin: typing.Union[
             bool,
             _kuber_definitions.InternalValue,
@@ -832,7 +826,6 @@ class CronJobSpec(_kuber_definitions.Definition):
             "readiness_probe": readiness_probe,
             "resources": resources,
             "security_context": security_context,
-            "startup_probe": startup_probe,
             "stdin": stdin,
             "stdin_once": stdin_once,
             "termination_message_path": termination_message_path,
@@ -995,8 +988,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
         """
         Standard object's metadata of the jobs created from this
         template. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return typing.cast(
             "ObjectMeta",
@@ -1008,8 +1001,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
         """
         Standard object's metadata of the jobs created from this
         template. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1022,8 +1015,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
     def spec(self) -> "JobSpec":
         """
         Specification of the desired behavior of the job. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#spec-and-status
         """
         return typing.cast(
             "JobSpec",
@@ -1034,8 +1027,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
     def spec(self, value: typing.Union["JobSpec", dict]):
         """
         Specification of the desired behavior of the job. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = typing.cast(
@@ -1098,10 +1091,6 @@ class JobTemplateSpec(_kuber_definitions.Definition):
             "SecurityContext",
             _kuber_definitions.InternalValue,
         ] = _kuber_definitions.UNCHANGED_VALUE,
-        startup_probe: typing.Union[
-            "Probe",
-            _kuber_definitions.InternalValue,
-        ] = _kuber_definitions.UNCHANGED_VALUE,
         stdin: typing.Union[
             bool,
             _kuber_definitions.InternalValue,
@@ -1150,7 +1139,6 @@ class JobTemplateSpec(_kuber_definitions.Definition):
             "readiness_probe": readiness_probe,
             "resources": resources,
             "security_context": security_context,
-            "startup_probe": startup_probe,
             "stdin": stdin,
             "stdin_once": stdin_once,
             "termination_message_path": termination_message_path,
