@@ -1,12 +1,12 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_19.meta_v1 import LabelSelector
-from kuber.v1_19.meta_v1 import ListMeta
-from kuber.v1_19.meta_v1 import ObjectMeta
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_15.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class AggregationRule(_kuber_definitions.Definition):
@@ -76,9 +76,7 @@ class ClusterRole(_kuber_definitions.Resource):
     """
     ClusterRole is a cluster level, logical grouping of
     PolicyRules that can be referenced as a unit by a
-    RoleBinding or ClusterRoleBinding. Deprecated in v1.17 in
-    favor of rbac.authorization.k8s.io/v1 ClusterRole, and will
-    no longer be served in v1.22.
+    RoleBinding or ClusterRoleBinding.
     """
 
     def __init__(
@@ -303,9 +301,7 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
     """
     ClusterRoleBinding references a ClusterRole, but not contain
     it.  It can reference a ClusterRole in the global namespace,
-    and adds who information via Subject. Deprecated in v1.17 in
-    favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding,
-    and will no longer be served in v1.22.
+    and adds who information via Subject.
     """
 
     def __init__(
@@ -533,9 +529,7 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
 class ClusterRoleBindingList(_kuber_definitions.Collection):
     """
     ClusterRoleBindingList is a collection of
-    ClusterRoleBindings. Deprecated in v1.17 in favor of
-    rbac.authorization.k8s.io/v1 ClusterRoleBindings, and will
-    no longer be served in v1.22.
+    ClusterRoleBindings
     """
 
     def __init__(
@@ -629,9 +623,7 @@ class ClusterRoleBindingList(_kuber_definitions.Collection):
 
 class ClusterRoleList(_kuber_definitions.Collection):
     """
-    ClusterRoleList is a collection of ClusterRoles. Deprecated
-    in v1.17 in favor of rbac.authorization.k8s.io/v1
-    ClusterRoles, and will no longer be served in v1.22.
+    ClusterRoleList is a collection of ClusterRoles
     """
 
     def __init__(
@@ -784,11 +776,14 @@ class PolicyRule(_kuber_definitions.Definition):
         """
         NonResourceURLs is a set of partial urls that a user should
         have access to.  *s are allowed, but only as the full, final
-        step in the path Since non-resource URLs are not namespaced,
-        this field is only applicable for ClusterRoles referenced
-        from a ClusterRoleBinding. Rules can either apply to API
-        resources (such as "pods" or "secrets") or non-resource URL
-        paths (such as "/api"),  but not both.
+        step in the path This name is intentionally different than
+        the internal type so that the DefaultConvert works nicely
+        and because the ordering may be different. Since non-
+        resource URLs are not namespaced, this field is only
+        applicable for ClusterRoles referenced from a
+        ClusterRoleBinding. Rules can either apply to API resources
+        (such as "pods" or "secrets") or non-resource URL paths
+        (such as "/api"),  but not both.
         """
         return typing.cast(
             typing.List[str],
@@ -800,11 +795,14 @@ class PolicyRule(_kuber_definitions.Definition):
         """
         NonResourceURLs is a set of partial urls that a user should
         have access to.  *s are allowed, but only as the full, final
-        step in the path Since non-resource URLs are not namespaced,
-        this field is only applicable for ClusterRoles referenced
-        from a ClusterRoleBinding. Rules can either apply to API
-        resources (such as "pods" or "secrets") or non-resource URL
-        paths (such as "/api"),  but not both.
+        step in the path This name is intentionally different than
+        the internal type so that the DefaultConvert works nicely
+        and because the ordering may be different. Since non-
+        resource URLs are not namespaced, this field is only
+        applicable for ClusterRoles referenced from a
+        ClusterRoleBinding. Rules can either apply to API resources
+        (such as "pods" or "secrets") or non-resource URL paths
+        (such as "/api"),  but not both.
         """
         self._properties["nonResourceURLs"] = value
 
@@ -879,9 +877,7 @@ class PolicyRule(_kuber_definitions.Definition):
 class Role(_kuber_definitions.Resource):
     """
     Role is a namespaced, logical grouping of PolicyRules that
-    can be referenced as a unit by a RoleBinding. Deprecated in
-    v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and
-    will no longer be served in v1.22.
+    can be referenced as a unit by a RoleBinding.
     """
 
     def __init__(
@@ -1076,9 +1072,7 @@ class RoleBinding(_kuber_definitions.Resource):
     in the global namespace. It adds who information via
     Subjects and namespace information by which namespace it
     exists in.  RoleBindings in a given namespace only have
-    effect in that namespace. Deprecated in v1.17 in favor of
-    rbac.authorization.k8s.io/v1 RoleBinding, and will no longer
-    be served in v1.22.
+    effect in that namespace.
     """
 
     def __init__(
@@ -1299,9 +1293,7 @@ class RoleBinding(_kuber_definitions.Resource):
 
 class RoleBindingList(_kuber_definitions.Collection):
     """
-    RoleBindingList is a collection of RoleBindings Deprecated
-    in v1.17 in favor of rbac.authorization.k8s.io/v1
-    RoleBindingList, and will no longer be served in v1.22.
+    RoleBindingList is a collection of RoleBindings
     """
 
     def __init__(
@@ -1392,9 +1384,7 @@ class RoleBindingList(_kuber_definitions.Collection):
 
 class RoleList(_kuber_definitions.Collection):
     """
-    RoleList is a collection of Roles. Deprecated in v1.17 in
-    favor of rbac.authorization.k8s.io/v1 RoleList, and will no
-    longer be served in v1.22.
+    RoleList is a collection of Roles
     """
 
     def __init__(
