@@ -1,16 +1,16 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_19.core_v1 import EnvFromSource
-from kuber.v1_19.core_v1 import EnvVar
-from kuber.v1_19.meta_v1 import LabelSelector
-from kuber.v1_19.meta_v1 import ListMeta
-from kuber.v1_19.meta_v1 import ObjectMeta
-from kuber.v1_19.core_v1 import Volume
-from kuber.v1_19.core_v1 import VolumeMount
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_15.core_v1 import EnvFromSource  # noqa: F401
+from kuber.v1_15.core_v1 import EnvVar  # noqa: F401
+from kuber.v1_15.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_15.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_15.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_15.core_v1 import Volume  # noqa: F401
+from kuber.v1_15.core_v1 import VolumeMount  # noqa: F401
 
 
 class PodPreset(_kuber_definitions.Resource):
