@@ -1,11 +1,11 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_21.meta_v1 import ListMeta
-from kuber.v1_21.meta_v1 import ObjectMeta
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_16.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_16.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class PriorityClass(_kuber_definitions.Resource):
@@ -125,8 +125,9 @@ class PriorityClass(_kuber_definitions.Resource):
         """
         PreemptionPolicy is the Policy for preempting pods with
         lower priority. One of Never, PreemptLowerPriority. Defaults
-        to PreemptLowerPriority if unset. This field is beta-level,
-        gated by the NonPreemptingPriority feature-gate.
+        to PreemptLowerPriority if unset. This field is alpha-level
+        and is only honored by servers that enable the
+        NonPreemptingPriority feature.
         """
         return typing.cast(
             str,
@@ -138,8 +139,9 @@ class PriorityClass(_kuber_definitions.Resource):
         """
         PreemptionPolicy is the Policy for preempting pods with
         lower priority. One of Never, PreemptLowerPriority. Defaults
-        to PreemptLowerPriority if unset. This field is beta-level,
-        gated by the NonPreemptingPriority feature-gate.
+        to PreemptLowerPriority if unset. This field is alpha-level
+        and is only honored by servers that enable the
+        NonPreemptingPriority feature.
         """
         self._properties["preemptionPolicy"] = value
 
