@@ -1,12 +1,12 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_19.meta_v1 import ListMeta
-from kuber.v1_19.meta_v1 import ObjectMeta
-from kuber.v1_19.core_v1 import ObjectReference
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_17.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_17.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_17.core_v1 import ObjectReference  # noqa: F401
 
 
 class Endpoint(_kuber_definitions.Definition):
@@ -289,8 +289,8 @@ class EndpointPort(_kuber_definitions.Definition):
         standard Kubernetes label syntax. Un-prefixed names are
         reserved for IANA standard service names (as per RFC-6335
         and http://www.iana.org/assignments/service-names). Non-
-        standard protocols should use prefixed names such as
-        mycompany.com/my-custom-protocol.
+        standard protocols should use prefixed names. Default is
+        empty string.
         """
         return typing.cast(
             str,
@@ -304,8 +304,8 @@ class EndpointPort(_kuber_definitions.Definition):
         standard Kubernetes label syntax. Un-prefixed names are
         reserved for IANA standard service names (as per RFC-6335
         and http://www.iana.org/assignments/service-names). Non-
-        standard protocols should use prefixed names such as
-        mycompany.com/my-custom-protocol.
+        standard protocols should use prefixed names. Default is
+        empty string.
         """
         self._properties["appProtocol"] = value
 
