@@ -1,21 +1,20 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_18.meta_v1 import LabelSelector
-from kuber.v1_18.meta_v1 import ListMeta
-from kuber.v1_18.meta_v1 import ObjectMeta
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_17.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_17.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_17.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class IPBlock(_kuber_definitions.Definition):
     """
-    IPBlock describes a particular CIDR (Ex.
-    "192.168.1.1/24","2001:db9::/64") that is allowed to the
-    pods matched by a NetworkPolicySpec's podSelector. The
-    except entry describes CIDRs that should not be included
-    within this rule.
+    IPBlock describes a particular CIDR (Ex. "192.168.1.1/24")
+    that is allowed to the pods matched by a NetworkPolicySpec's
+    podSelector. The except entry describes CIDRs that should
+    not be included within this rule.
     """
 
     def __init__(
@@ -38,7 +37,7 @@ class IPBlock(_kuber_definitions.Definition):
     def cidr(self) -> str:
         """
         CIDR is a string representing the IP Block Valid examples
-        are "192.168.1.1/24" or "2001:db9::/64"
+        are "192.168.1.1/24"
         """
         return typing.cast(
             str,
@@ -49,7 +48,7 @@ class IPBlock(_kuber_definitions.Definition):
     def cidr(self, value: str):
         """
         CIDR is a string representing the IP Block Valid examples
-        are "192.168.1.1/24" or "2001:db9::/64"
+        are "192.168.1.1/24"
         """
         self._properties["cidr"] = value
 
@@ -57,9 +56,9 @@ class IPBlock(_kuber_definitions.Definition):
     def except_(self) -> typing.List[str]:
         """
         Except is a slice of CIDRs that should not be included
-        within an IP Block Valid examples are "192.168.1.1/24" or
-        "2001:db9::/64" Except values will be rejected if they are
-        outside the CIDR range
+        within an IP Block Valid examples are "192.168.1.1/24"
+        Except values will be rejected if they are outside the CIDR
+        range
         """
         return typing.cast(
             typing.List[str],
@@ -70,9 +69,9 @@ class IPBlock(_kuber_definitions.Definition):
     def except_(self, value: typing.List[str]):
         """
         Except is a slice of CIDRs that should not be included
-        within an IP Block Valid examples are "192.168.1.1/24" or
-        "2001:db9::/64" Except values will be rejected if they are
-        outside the CIDR range
+        within an IP Block Valid examples are "192.168.1.1/24"
+        Except values will be rejected if they are outside the CIDR
+        range
         """
         self._properties["except"] = value
 
