@@ -1,12 +1,12 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_19.meta_v1 import LabelSelector
-from kuber.v1_19.meta_v1 import ListMeta
-from kuber.v1_19.meta_v1 import ObjectMeta
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_18.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_18.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_18.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class MutatingWebhook(_kuber_definitions.Definition):
@@ -941,10 +941,8 @@ class RuleWithOperations(_kuber_definitions.Definition):
     def operations(self) -> typing.List[str]:
         """
         Operations is the operations the admission hook cares about
-        - CREATE, UPDATE, DELETE, CONNECT or * for all of those
-        operations and any future admission operations that are
-        added. If '*' is present, the length of the slice must be
-        one. Required.
+        - CREATE, UPDATE, or * for all operations. If '*' is
+        present, the length of the slice must be one. Required.
         """
         return typing.cast(
             typing.List[str],
@@ -955,10 +953,8 @@ class RuleWithOperations(_kuber_definitions.Definition):
     def operations(self, value: typing.List[str]):
         """
         Operations is the operations the admission hook cares about
-        - CREATE, UPDATE, DELETE, CONNECT or * for all of those
-        operations and any future admission operations that are
-        added. If '*' is present, the length of the slice must be
-        one. Required.
+        - CREATE, UPDATE, or * for all operations. If '*' is
+        present, the length of the slice must be one. Required.
         """
         self._properties["operations"] = value
 
