@@ -1,12 +1,12 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_21.meta_v1 import ListMeta
-from kuber.v1_21.meta_v1 import MicroTime
-from kuber.v1_21.meta_v1 import ObjectMeta
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_18.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_18.meta_v1 import MicroTime  # noqa: F401
+from kuber.v1_18.meta_v1 import ObjectMeta  # noqa: F401
 
 
 class Lease(_kuber_definitions.Resource):
