@@ -1,14 +1,14 @@
-import typing
-import datetime as _datetime
+import typing  # noqa: F401
+import datetime as _datetime  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_15.meta_v1 import ListMeta
-from kuber.v1_15.meta_v1 import ObjectMeta
-from kuber.v1_15.meta_v1 import Status
-from kuber.v1_15.meta_v1 import StatusDetails
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_19.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_19.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_19.meta_v1 import Status  # noqa: F401
+from kuber.v1_19.meta_v1 import StatusDetails  # noqa: F401
 
 
 class APIService(_kuber_definitions.Resource):
@@ -174,7 +174,10 @@ class APIService(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_api_service", "read_api_service"]
+        names = [
+            "read_namespaced_api_service",
+            "read_api_service",
+        ]
 
         response = _kube_api.execute(
             action="read",
@@ -628,7 +631,7 @@ class APIServiceSpec(_kuber_definitions.Definition):
     def service(self) -> "ServiceReference":
         """
         Service is a reference to the service for this API server.
-        It must communicate on port 443 If the Service is nil, that
+        It must communicate on port 443. If the Service is nil, that
         means the handling for the API groupversion is handled
         locally on this server. The call will simply delegate to the
         normal handler chain to be fulfilled.
@@ -642,7 +645,7 @@ class APIServiceSpec(_kuber_definitions.Definition):
     def service(self, value: typing.Union["ServiceReference", dict]):
         """
         Service is a reference to the service for this API server.
-        It must communicate on port 443 If the Service is nil, that
+        It must communicate on port 443. If the Service is nil, that
         means the handling for the API groupversion is handled
         locally on this server. The call will simply delegate to the
         normal handler chain to be fulfilled.
