@@ -1,15 +1,275 @@
-import typing
-import datetime as _datetime
+import typing  # noqa: F401
+import datetime as _datetime  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_16.meta_v1 import LabelSelector
-from kuber.v1_16.meta_v1 import ListMeta
-from kuber.v1_16.meta_v1 import ObjectMeta
-from kuber.v1_16.meta_v1 import Status
-from kuber.v1_16.meta_v1 import StatusDetails
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_20.meta_v1 import LabelSelector  # noqa: F401
+from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import Status  # noqa: F401
+from kuber.v1_20.meta_v1 import StatusDetails  # noqa: F401
+
+
+class ContainerResourceMetricSource(_kuber_definitions.Definition):
+    """
+    ContainerResourceMetricSource indicates how to scale on a
+    resource metric known to Kubernetes, as specified in
+    requests and limits, describing each pod in the current
+    scale target (e.g. CPU or memory).  The values will be
+    averaged together before being compared to the target.  Such
+    metrics are built in to Kubernetes, and have special scaling
+    options on top of those available to normal per-pod metrics
+    using the "pods" source.  Only one "target" type should be
+    set.
+    """
+
+    def __init__(
+        self,
+        container: str = None,
+        name: str = None,
+        target_average_utilization: int = None,
+        target_average_value: typing.Union[str, int, None] = None,
+    ):
+        """Create ContainerResourceMetricSource instance."""
+        super(ContainerResourceMetricSource, self).__init__(
+            api_version="autoscaling/v2beta1", kind="ContainerResourceMetricSource"
+        )
+        self._properties = {
+            "container": container if container is not None else "",
+            "name": name if name is not None else "",
+            "targetAverageUtilization": target_average_utilization
+            if target_average_utilization is not None
+            else None,
+            "targetAverageValue": target_average_value
+            if target_average_value is not None
+            else None,
+        }
+        self._types = {
+            "container": (str, None),
+            "name": (str, None),
+            "targetAverageUtilization": (int, None),
+            "targetAverageValue": (str, None),
+        }
+
+    @property
+    def container(self) -> str:
+        """
+        container is the name of the container in the pods of the
+        scaling target
+        """
+        return typing.cast(
+            str,
+            self._properties.get("container"),
+        )
+
+    @container.setter
+    def container(self, value: str):
+        """
+        container is the name of the container in the pods of the
+        scaling target
+        """
+        self._properties["container"] = value
+
+    @property
+    def name(self) -> str:
+        """
+        name is the name of the resource in question.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("name"),
+        )
+
+    @name.setter
+    def name(self, value: str):
+        """
+        name is the name of the resource in question.
+        """
+        self._properties["name"] = value
+
+    @property
+    def target_average_utilization(self) -> int:
+        """
+        targetAverageUtilization is the target value of the average
+        of the resource metric across all relevant pods, represented
+        as a percentage of the requested value of the resource for
+        the pods.
+        """
+        return typing.cast(
+            int,
+            self._properties.get("targetAverageUtilization"),
+        )
+
+    @target_average_utilization.setter
+    def target_average_utilization(self, value: int):
+        """
+        targetAverageUtilization is the target value of the average
+        of the resource metric across all relevant pods, represented
+        as a percentage of the requested value of the resource for
+        the pods.
+        """
+        self._properties["targetAverageUtilization"] = value
+
+    @property
+    def target_average_value(self) -> typing.Optional[str]:
+        """
+        targetAverageValue is the target value of the average of the
+        resource metric across all relevant pods, as a raw value
+        (instead of as a percentage of the request), similar to the
+        "pods" metric source type.
+        """
+        value = self._properties.get("targetAverageValue")
+        return f"{value}" if value is not None else None
+
+    @target_average_value.setter
+    def target_average_value(self, value: typing.Union[str, int, None]):
+        """
+        targetAverageValue is the target value of the average of the
+        resource metric across all relevant pods, as a raw value
+        (instead of as a percentage of the request), similar to the
+        "pods" metric source type.
+        """
+        self._properties["targetAverageValue"] = None if value is None else f"{value}"
+
+    def __enter__(self) -> "ContainerResourceMetricSource":
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
+
+
+class ContainerResourceMetricStatus(_kuber_definitions.Definition):
+    """
+    ContainerResourceMetricStatus indicates the current value of
+    a resource metric known to Kubernetes, as specified in
+    requests and limits, describing a single container in each
+    pod in the current scale target (e.g. CPU or memory).  Such
+    metrics are built in to Kubernetes, and have special scaling
+    options on top of those available to normal per-pod metrics
+    using the "pods" source.
+    """
+
+    def __init__(
+        self,
+        container: str = None,
+        current_average_utilization: int = None,
+        current_average_value: typing.Union[str, int, None] = None,
+        name: str = None,
+    ):
+        """Create ContainerResourceMetricStatus instance."""
+        super(ContainerResourceMetricStatus, self).__init__(
+            api_version="autoscaling/v2beta1", kind="ContainerResourceMetricStatus"
+        )
+        self._properties = {
+            "container": container if container is not None else "",
+            "currentAverageUtilization": current_average_utilization
+            if current_average_utilization is not None
+            else None,
+            "currentAverageValue": current_average_value
+            if current_average_value is not None
+            else None,
+            "name": name if name is not None else "",
+        }
+        self._types = {
+            "container": (str, None),
+            "currentAverageUtilization": (int, None),
+            "currentAverageValue": (str, None),
+            "name": (str, None),
+        }
+
+    @property
+    def container(self) -> str:
+        """
+        container is the name of the container in the pods of the
+        scaling target
+        """
+        return typing.cast(
+            str,
+            self._properties.get("container"),
+        )
+
+    @container.setter
+    def container(self, value: str):
+        """
+        container is the name of the container in the pods of the
+        scaling target
+        """
+        self._properties["container"] = value
+
+    @property
+    def current_average_utilization(self) -> int:
+        """
+        currentAverageUtilization is the current value of the
+        average of the resource metric across all relevant pods,
+        represented as a percentage of the requested value of the
+        resource for the pods.  It will only be present if
+        `targetAverageValue` was set in the corresponding metric
+        specification.
+        """
+        return typing.cast(
+            int,
+            self._properties.get("currentAverageUtilization"),
+        )
+
+    @current_average_utilization.setter
+    def current_average_utilization(self, value: int):
+        """
+        currentAverageUtilization is the current value of the
+        average of the resource metric across all relevant pods,
+        represented as a percentage of the requested value of the
+        resource for the pods.  It will only be present if
+        `targetAverageValue` was set in the corresponding metric
+        specification.
+        """
+        self._properties["currentAverageUtilization"] = value
+
+    @property
+    def current_average_value(self) -> typing.Optional[str]:
+        """
+        currentAverageValue is the current value of the average of
+        the resource metric across all relevant pods, as a raw value
+        (instead of as a percentage of the request), similar to the
+        "pods" metric source type. It will always be set, regardless
+        of the corresponding metric specification.
+        """
+        value = self._properties.get("currentAverageValue")
+        return f"{value}" if value is not None else None
+
+    @current_average_value.setter
+    def current_average_value(self, value: typing.Union[str, int, None]):
+        """
+        currentAverageValue is the current value of the average of
+        the resource metric across all relevant pods, as a raw value
+        (instead of as a percentage of the request), similar to the
+        "pods" metric source type. It will always be set, regardless
+        of the corresponding metric specification.
+        """
+        self._properties["currentAverageValue"] = None if value is None else f"{value}"
+
+    @property
+    def name(self) -> str:
+        """
+        name is the name of the resource in question.
+        """
+        return typing.cast(
+            str,
+            self._properties.get("name"),
+        )
+
+    @name.setter
+    def name(self, value: str):
+        """
+        name is the name of the resource in question.
+        """
+        self._properties["name"] = value
+
+    def __enter__(self) -> "ContainerResourceMetricStatus":
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
 
 
 class CrossVersionObjectReference(_kuber_definitions.Definition):
@@ -1216,6 +1476,7 @@ class MetricSpec(_kuber_definitions.Definition):
 
     def __init__(
         self,
+        container_resource: "ContainerResourceMetricSource" = None,
         external: "ExternalMetricSource" = None,
         object_: "ObjectMetricSource" = None,
         pods: "PodsMetricSource" = None,
@@ -1227,6 +1488,9 @@ class MetricSpec(_kuber_definitions.Definition):
             api_version="autoscaling/v2beta1", kind="MetricSpec"
         )
         self._properties = {
+            "containerResource": container_resource
+            if container_resource is not None
+            else ContainerResourceMetricSource(),
             "external": external if external is not None else ExternalMetricSource(),
             "object": object_ if object_ is not None else ObjectMetricSource(),
             "pods": pods if pods is not None else PodsMetricSource(),
@@ -1234,6 +1498,7 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
+            "containerResource": (ContainerResourceMetricSource, None),
             "external": (ExternalMetricSource, None),
             "object": (ObjectMetricSource, None),
             "pods": (PodsMetricSource, None),
@@ -1241,6 +1506,44 @@ class MetricSpec(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
+    @property
+    def container_resource(self) -> "ContainerResourceMetricSource":
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod of the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source. This is an alpha feature and can be enabled by the
+        HPAContainerMetrics feature flag.
+        """
+        return typing.cast(
+            "ContainerResourceMetricSource",
+            self._properties.get("containerResource"),
+        )
+
+    @container_resource.setter
+    def container_resource(
+        self, value: typing.Union["ContainerResourceMetricSource", dict]
+    ):
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod of the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source. This is an alpha feature and can be enabled by the
+        HPAContainerMetrics feature flag.
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                ContainerResourceMetricSource,
+                ContainerResourceMetricSource().from_dict(value),
+            )
+        self._properties["containerResource"] = value
+
     @property
     def external(self) -> "ExternalMetricSource":
         """
@@ -1361,8 +1664,10 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It should be one of
-        "Object", "Pods" or "Resource", each mapping to a matching
-        field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each mapping to a matching field in the object.
+        Note: "ContainerResource" type is available on when the
+        feature-gate HPAContainerMetrics is enabled
         """
         return typing.cast(
             str,
@@ -1373,8 +1678,10 @@ class MetricSpec(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It should be one of
-        "Object", "Pods" or "Resource", each mapping to a matching
-        field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each mapping to a matching field in the object.
+        Note: "ContainerResource" type is available on when the
+        feature-gate HPAContainerMetrics is enabled
         """
         self._properties["type"] = value
 
@@ -1393,6 +1700,7 @@ class MetricStatus(_kuber_definitions.Definition):
 
     def __init__(
         self,
+        container_resource: "ContainerResourceMetricStatus" = None,
         external: "ExternalMetricStatus" = None,
         object_: "ObjectMetricStatus" = None,
         pods: "PodsMetricStatus" = None,
@@ -1404,6 +1712,9 @@ class MetricStatus(_kuber_definitions.Definition):
             api_version="autoscaling/v2beta1", kind="MetricStatus"
         )
         self._properties = {
+            "containerResource": container_resource
+            if container_resource is not None
+            else ContainerResourceMetricStatus(),
             "external": external if external is not None else ExternalMetricStatus(),
             "object": object_ if object_ is not None else ObjectMetricStatus(),
             "pods": pods if pods is not None else PodsMetricStatus(),
@@ -1411,6 +1722,7 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": type_ if type_ is not None else "",
         }
         self._types = {
+            "containerResource": (ContainerResourceMetricStatus, None),
             "external": (ExternalMetricStatus, None),
             "object": (ObjectMetricStatus, None),
             "pods": (PodsMetricStatus, None),
@@ -1418,6 +1730,42 @@ class MetricStatus(_kuber_definitions.Definition):
             "type": (str, None),
         }
 
+    @property
+    def container_resource(self) -> "ContainerResourceMetricStatus":
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod in the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source.
+        """
+        return typing.cast(
+            "ContainerResourceMetricStatus",
+            self._properties.get("containerResource"),
+        )
+
+    @container_resource.setter
+    def container_resource(
+        self, value: typing.Union["ContainerResourceMetricStatus", dict]
+    ):
+        """
+        container resource refers to a resource metric (such as
+        those specified in requests and limits) known to Kubernetes
+        describing a single container in each pod in the current
+        scale target (e.g. CPU or memory). Such metrics are built in
+        to Kubernetes, and have special scaling options on top of
+        those available to normal per-pod metrics using the "pods"
+        source.
+        """
+        if isinstance(value, dict):
+            value = typing.cast(
+                ContainerResourceMetricStatus,
+                ContainerResourceMetricStatus().from_dict(value),
+            )
+        self._properties["containerResource"] = value
+
     @property
     def external(self) -> "ExternalMetricStatus":
         """
@@ -1538,8 +1886,10 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self) -> str:
         """
         type is the type of metric source.  It will be one of
-        "Object", "Pods" or "Resource", each corresponds to a
-        matching field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each corresponds to a matching field in the
+        object. Note: "ContainerResource" type is available on when
+        the feature-gate HPAContainerMetrics is enabled
         """
         return typing.cast(
             str,
@@ -1550,8 +1900,10 @@ class MetricStatus(_kuber_definitions.Definition):
     def type_(self, value: str):
         """
         type is the type of metric source.  It will be one of
-        "Object", "Pods" or "Resource", each corresponds to a
-        matching field in the object.
+        "ContainerResource", "External", "Object", "Pods" or
+        "Resource", each corresponds to a matching field in the
+        object. Note: "ContainerResource" type is available on when
+        the feature-gate HPAContainerMetrics is enabled
         """
         self._properties["type"] = value
 
