@@ -1,14 +1,14 @@
-import typing
-import datetime as _datetime
+import typing  # noqa: F401
+import datetime as _datetime  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_20.meta_v1 import ListMeta
-from kuber.v1_20.meta_v1 import ObjectMeta
-from kuber.v1_20.meta_v1 import Status
-from kuber.v1_20.meta_v1 import StatusDetails
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_20.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_20.meta_v1 import Status  # noqa: F401
+from kuber.v1_20.meta_v1 import StatusDetails  # noqa: F401
 
 
 class FlowDistinguisherMethod(_kuber_definitions.Definition):
@@ -239,7 +239,10 @@ class FlowSchema(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_flow_schema", "read_flow_schema"]
+        names = [
+            "read_namespaced_flow_schema",
+            "read_flow_schema",
+        ]
 
         response = _kube_api.execute(
             action="read",
