@@ -1,13 +1,13 @@
-import typing
+import typing  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_16.meta_v1 import ListMeta
-from kuber.v1_16.meta_v1 import ObjectMeta
-from kuber.v1_16.meta_v1 import Status
-from kuber.v1_16.meta_v1 import StatusDetails
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_21.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_21.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_21.meta_v1 import Status  # noqa: F401
+from kuber.v1_21.meta_v1 import StatusDetails  # noqa: F401
 
 
 class LocalSubjectAccessReview(_kuber_definitions.Resource):
@@ -1561,7 +1561,10 @@ class SubjectAccessReview(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_subject_access_review", "read_subject_access_review"]
+        names = [
+            "read_namespaced_subject_access_review",
+            "read_subject_access_review",
+        ]
 
         response = _kube_api.execute(
             action="read",
