@@ -1,16 +1,16 @@
-import typing
-import datetime as _datetime
+import typing  # noqa: F401
+import datetime as _datetime  # noqa: F401
 
-from kubernetes import client
-from kuber import kube_api as _kube_api
+from kubernetes import client  # noqa: F401
+from kuber import kube_api as _kube_api  # noqa: F401
 
-from kuber import definitions as _kuber_definitions
-from kuber.v1_21.meta_v1 import ListMeta
-from kuber.v1_21.meta_v1 import ObjectMeta
-from kuber.v1_21.core_v1 import PersistentVolumeSpec
-from kuber.v1_21.meta_v1 import Status
-from kuber.v1_21.meta_v1 import StatusDetails
-from kuber.v1_21.core_v1 import TopologySelectorTerm
+from kuber import definitions as _kuber_definitions  # noqa: F401
+from kuber.v1_21.meta_v1 import ListMeta  # noqa: F401
+from kuber.v1_21.meta_v1 import ObjectMeta  # noqa: F401
+from kuber.v1_21.core_v1 import PersistentVolumeSpec  # noqa: F401
+from kuber.v1_21.meta_v1 import Status  # noqa: F401
+from kuber.v1_21.meta_v1 import StatusDetails  # noqa: F401
+from kuber.v1_21.core_v1 import TopologySelectorTerm  # noqa: F401
 
 
 class CSIDriver(_kuber_definitions.Resource):
@@ -1914,7 +1914,10 @@ class VolumeAttachment(_kuber_definitions.Resource):
         """
         Returns status information about the given resource within the cluster.
         """
-        names = ["read_namespaced_volume_attachment", "read_volume_attachment"]
+        names = [
+            "read_namespaced_volume_attachment",
+            "read_volume_attachment",
+        ]
 
         response = _kube_api.execute(
             action="read",
